#!/usr/bin/python3

# Copyright (C) 2020  Daniele Parmeggiani
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import sys


DEFAULT_BEGIN = ':SPOILERS BEGIN:'
DEFAULT_END = ':SPOILERS END:'


class DespoilerizerException(Exception):
    pass


class BeginTagInsideSpoilerBlock(DespoilerizerException):
    def __init__(self, line_no):
        self.line_no = line_no
        self.string = f'Found beginning of spoilers tag on line #{line_no} ' \
                      f'while already in a spoiler block.'
        super().__init__(self.string)


class EndTagOutsideSpoilerBlock(DespoilerizerException):
    def __init__(self, line_no):
        self.line_no = line_no
        self.string = f'Found ending of spoilers tag on line #{line_no} ' \
                      f'while outside of a spoiler block.'
        super().__init__(self.string)


def despoilerize(string, begin=DEFAULT_BEGIN, end=DEFAULT_END):
    result = []
    in_spoiler = False
    for i, line in enumerate(string.split('\n')):
        if line.find(begin) > -1:
            if in_spoiler:
                raise BeginTagInsideSpoilerBlock(i)
            else:
                in_spoiler = True
        elif line.find(end) > -1:
            if not in_spoiler:
                raise EndTagOutsideSpoilerBlock(i)
            else:
                in_spoiler = False
        else:
            if not in_spoiler:
                result.append(line)
            else:
                pass
    return '\n'.join(result)


def despoilerize_file(input_file, output_file, begin=DEFAULT_BEGIN, end=DEFAULT_END):
    despoilerized = despoilerize(input_file.read(), begin, end)
    output_file.write(despoilerized)


def despoilerize_stdin(begin=DEFAULT_BEGIN, end=DEFAULT_END):
    """
    Runs the `despoilerizer` function with `sys.stdin` as input and `sys.stdout`
    as output.
    """
    sys.stdout.write(
        despoilerize(sys.stdin.read(), begin=begin, end=end)
    )



#!/usr/bin/python3

# Copyright (C) 2020  Daniele Parmeggiani
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


class Version:
    major = 1
    minor = 0
    patch = 1
    notes = ''
    string = '.'.join((str(major), str(minor), str(patch))) + notes

    @property
    def as_tuple(self):
        return (self.major, self.minor, self.patch, self.notes)

    @property
    def as_string(self):
        return '.'.join((str(self.major), str(self.minor), str(self.patch))) + \
               self.notes


__title__ = 'despoilerizer'
__description__ = 'Remove spoilers from files.'
__url__ = 'https://github.com/dpdani/despoilerizer'
__version__ = Version()
__author__ = 'Daniele Parmeggiani'
__author_email__ = 'git@danieleparmeggiani.me'
__license__ = 'GPLv3'
__copyright__ = 'Copyright (C) 2020 Daniele Parmeggiani'


__all__ = [
    '__title__',
    '__description__',
    '__url__',
    '__version__',
    '__author__',
    '__author_email__',
    '__license__',
    '__copyright__',
]



#!/usr/bin/python3

# Copyright (C) 2020  Daniele Parmeggiani
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from . import core
from .__version__ import *
import click
import sys


@click.command()
@click.option('-b', '--begin', default=':SPOILERS BEGIN:',
              help='Tag for beginning of spoilers.')
@click.option('-e', '--end', default=':SPOILERS END:',
              help='Tag for ending of spoilers.')
@click.option('-f', '--file', type=click.Path(),
              help='Read from file PATH instead of STDIN.')
@click.option('-o', '--output', type=click.Path(),
              help='Write to file PATH instead of STDOUT. '
                   'Only usable in conjunction with the -f option.')
def main(begin, end, file, output):
    if file is not None:
        with open(file, 'r') as fin:
            if output is not None:
                with open(output, 'w') as fout:
                    core.despoilerize_file(
                        input_file=fin, output_file=fout,
                        begin=begin, end=end
                    )
            else:
                core.despoilerize_file(
                    input_file=fin, output_file=sys.stdout,
                    begin=begin, end=end
                )
    else:
        core.despoilerize_stdin(begin=begin, end=end)
    return 0


main.__doc__ = f"""
{__title__} version {__version__.string}.

{__description__}
See README for example usages.

{__url__}

By {__author__} <{__author_email__}>.
""".strip()

main.help = main.__doc__


main()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['despoilerizer']

package_data = \
{'': ['*']}

install_requires = \
['click']

setup_kwargs = {
    'name': 'despoilerizer',
    'version': '1.0.1',
    'description': 'Remove spoilers from files.',
    'long_description': '# Despoilerizer\n\nThis script reads from stdin and prints out the contents of stdin to stdout,\nwithout the lines that are in between the `:SPOILERS BEGIN:` and the\n`:SPOILERS END:` tags.\n\nIt uses stdin and stdout so that it can be easily integrated in bash \nscripting, for instance:\n```bash\n$ <my_file.tex | python -m despoilerizer | pdflatex\n```\n\nYou can also redefine the tags:\n\n```bash\n$ <my_file.tex | \\\n  python -m despoilerizer --begin="# spoiler" --end="# unspoiler" | \\\n  pdflatex\n```\n\n## Installation\n\n```bash\n$ pip install despoilerizer\n```\n\n## Examples\n\n#### stdin\n```\nThis is a simple file.\n:SPOILERS BEGIN:\nIt contains spoilers.\n:SPOILERS END:\nAnd also other information.\n```\n\n#### stdout\n```\nThis is a simple file.\nAnd also other information.\n```\n\n#### stdin\n```\n\\begin{document}\n% :SPOILERS BEGIN:\nimportant stuff...\n% :SPOILERS END:\n\\end{document}\n```\n\n#### stdout\n```\n\\begin{document}\n\\end{document}\n```\n\n## Usage as importable package\n\n```python\nimport despoilerizer\nfrom pathlib import Path as P\n\nfor path in [P(\'file1.tex\'), P(\'file2.py\'), P(\'file3.txt\')]:\n    out_path = P(path.stem + \'_nospoilers\' + path.suffix)\n    with open(path, \'r\') as fin:\n        with open(out_path, \'w\') as fout:\n            despoilerizer.despoilerize_file(fin, fout)\n\n\ncontents = """\nThis is a very important string.\nsuch spoilers\nI really don\'t want anyone to know.\nmuch wow\n"""\n\nwith open(P(\'some_file.txt\'), \'w\') as f:\n    f.write(\n        despoilerizer.despoilerize(contents, begin=\'such spoilers\', end=\'much wow\')\n    )\n```\n\n## Motivation\n\nI have a LaTeX file for a document I\'m sharing with my friends.\nThis document contains some information for a DnD campaign both for stuff the \nplayers have encountered and stuff that\'s being worked on.\n\nTherefore, I want to have two different PDF documents: one with the spoilers\nand one without them.\n',
    'author': 'Daniele Parmeggiani',
    'author_email': 'git@danieleparmeggiani.me',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/dpdani/despoilerizer',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6',
}


setup(**setup_kwargs)
